@@ -19,7 +19,8 @@
 /* Code for cookie handling. This really needs to be modularized to
  * support other XAuth types and possibly DECnet... */
 
-#include <config.h>
+#include "config.h"
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -722,7 +723,11 @@ try_user_add_again:
 	d->userauth = NULL;
 
 	umask (022);
-
+	/* check if authdir is fallback dir if not try it with the fallback dir */
+	if (strcmp(gdm_get_value_string (GDM_KEY_USER_AUTHDIR_FALLBACK),authdir) != 0 ){
+		authdir = gdm_get_value_string (GDM_KEY_USER_AUTHDIR_FALLBACK); 
+		goto try_user_add_again;
+	}
 	if ( ! d->authfb) {
 		automatic_tmp_dir = TRUE;
 		goto try_user_add_again;
@@ -981,7 +986,7 @@ gdm_auth_purge (GdmDisplay *d, FILE *af, gboolean remove_when_empty)
 		keep = g_slist_append (keep, xa);
 
 	/* just being ultra anal */
-	cnt ++;
+	cnt++;
 	if (cnt > 500)
 		break;
     }
